@@ -10,7 +10,7 @@ import multiprocessing
 import time
 import plistlib
 import socket
-import pyping
+import subprocess
 
 
 LOGGER = logging.getLogger(__name__)
@@ -89,8 +89,8 @@ def client_ping_response(client):
     False == client is not
 
     """
-    ping_response = pyping.ping(client.ip_address, count=4)
-    return ping_response.ret_code
+    ping_response = subprocess.call(['/sbin/ping', '-c1', client.ip_address])
+    return ping_response
 
 
 def parse_client_io_data(client, io_data):
